@@ -404,7 +404,7 @@ function fillRowWithFlex(aRow)
 
 /**
  * Makes sure that an item that has been cloned from a template
- * is stripped of all properties that may adversely affect its
+ * is stripped of any attributes that may adversely affect its
  * appearance in the palette.
  */
 function cleanUpItemForPalette(aItem, aWrapper)
@@ -420,17 +420,18 @@ function cleanUpItemForPalette(aItem, aWrapper)
     var title = stringBundle.getString(aItem.localName.slice(7) + "Title");
     aWrapper.setAttribute("title", title);
   }
-  
+ 
   // Remove attributes that screw up our appearance.
   aItem.removeAttribute("command");
   aItem.removeAttribute("observes");
-  aItem.removeAttribute("disabled");
   aItem.removeAttribute("type");
   aItem.removeAttribute("width");
-  
-  if (aItem.localName == "toolbaritem" && aItem.firstChild) {
-    aItem.firstChild.removeAttribute("observes");
 
+  Array.forEach(aWrapper.querySelectorAll("[disabled]"), function(aNode) {
+    aNode.removeAttribute("disabled");
+  });
+
+  if (aItem.localName == "toolbaritem" && aItem.firstChild) {
     // So the throbber doesn't throb in the dialog,
     // cute as that may be...
     aItem.firstChild.removeAttribute("busy");
