@@ -1,8 +1,8 @@
-//@line 41 "/builds/buildbot/fx-linux64-1.9-slave1/linux64_nightly_build/mozilla/toolkit/components/printing/content/printjoboptions.js"
+//@line 41 "/builds/slave/mozilla-1.9.1-linux64-nightly/build/toolkit/components/printing/content/printjoboptions.js"
 
 var dialog;
+var gPrintBundle;
 var gPrintSettings = null;
-var gStringBundle  = null;
 var gPrintSettingsInterface  = Components.interfaces.nsIPrintSettings;
 var gPaperArray;
 var gPlexArray;
@@ -56,6 +56,8 @@ function getDoubleStr(val, dec)
 //---------------------------------------------------
 function initDialog()
 {
+  gPrintBundle = document.getElementById("printBundle");
+
   dialog = new Object;
 
   dialog.paperList       = document.getElementById("paperList");
@@ -123,7 +125,7 @@ paperListElement.prototype =
             var itemNode = document.createElement("menuitem");
             var label;
             try {
-              label = gStringBundle.GetStringFromName(paperObj.name)
+              label = gPrintBundle.getString(paperObj.name);
             } 
             catch (e) {
               /* No name in string bundle ? Then build one manually (this
@@ -231,8 +233,6 @@ function createPaperArray()
 //---------------------------------------------------
 function createPaperSizeList(selectedInx)
 {
-  gStringBundle = srGetStrBundle("chrome://global/locale/printPageSetup.properties");
-
   var selectElement = new paperListElement(dialog.paperList);
   selectElement.clearPaperList();
 
@@ -269,7 +269,7 @@ plexListElement.prototype =
             var itemNode = document.createElement("menuitem");
             var label;
             try {
-              label = gStringBundle.GetStringFromName(plexObj.name)
+              label = gPrintBundle.getString(plexObj.name);
             } 
             catch (e) {
               /* No name in string bundle ? Then build one manually (this
@@ -342,8 +342,6 @@ function createPlexArray()
 //---------------------------------------------------
 function createPlexNameList(selectedInx)
 {
-  gStringBundle = srGetStrBundle("chrome://global/locale/printPageSetup.properties");
-
   var selectElement = new plexListElement(dialog.plexList);
   selectElement.clearPlexList();
 
@@ -380,7 +378,7 @@ resolutionListElement.prototype =
             var itemNode = document.createElement("menuitem");
             var label;
             try {
-              label = gStringBundle.GetStringFromName(resolutionObj.name)
+              label = gPrintBundle.getString(resolutionObj.name);
             } 
             catch (e) {
               /* No name in string bundle ? Then build one manually (this
@@ -453,8 +451,6 @@ function createResolutionArray()
 //---------------------------------------------------
 function createResolutionNameList(selectedInx)
 {
-  gStringBundle = srGetStrBundle("chrome://global/locale/printPageSetup.properties");
-
   var selectElement = new resolutionListElement(dialog.resolutionList);
   selectElement.clearResolutionList();
 
@@ -491,7 +487,7 @@ colorspaceListElement.prototype =
             var itemNode = document.createElement("menuitem");
             var label;
             try {
-              label = gStringBundle.GetStringFromName(colorspaceObj.name)
+              label = gPrintBundle.getString(colorspaceObj.name);
             } 
             catch (e) {
               /* No name in string bundle ? Then build one manually (this
@@ -564,8 +560,6 @@ function createColorspaceArray()
 //---------------------------------------------------
 function createColorspaceNameList(selectedInx)
 {
-  gStringBundle = srGetStrBundle("chrome://global/locale/printPageSetup.properties");
-
   var selectElement = new colorspaceListElement(dialog.colorspaceList);
   selectElement.clearColorspaceList();
 
